OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Lades till i favoriter",
    "Removed from favorites" : "Togs bort från favoriter",
    "You added {file} to your favorites" : "Du la till {file} till dina favoriter",
    "You removed {file} from your favorites" : "Du tog bort {file} från dina favoriter",
    "Favorites" : "Favoriter",
    "File changes" : "Filändringar",
    "Created by {user}" : "Skapad av {user}",
    "Changed by {user}" : "Ändrad av {user}",
    "Deleted by {user}" : "Raderad av {user}",
    "Restored by {user}" : "Återställd av {user}",
    "Renamed by {user}" : "Filnamn ändrat av {user}",
    "Moved by {user}" : "Flyttad av {user}",
    "\"remote account\"" : "\"externt konto\"",
    "You created {file}" : "Du skapade {file}",
    "You created an encrypted file in {file}" : "Du skapade en krypterad fil i {file}",
    "{user} created {file}" : "{user} skapade {file}",
    "{user} created an encrypted file in {file}" : "{user} skapade en krypterad fil i {file}",
    "{file} was created in a public folder" : "{file} skapades i en offentlig mapp",
    "You changed {file}" : "Du ändrade {file}",
    "You changed an encrypted file in {file}" : "Du ändrade en krypterad fil i {file}",
    "{user} changed {file}" : "{user} ändrade {file}",
    "{user} changed an encrypted file in {file}" : "{user} ändrade en krypterad fil i {file}",
    "You deleted {file}" : "Du raderade {file}",
    "You deleted an encrypted file in {file}" : "Du tog bort en krypterad fil i {file}",
    "{user} deleted {file}" : "{user} raderade {file}",
    "{user} deleted an encrypted file in {file}" : "{user} tog bort en krypterad fil i {file}",
    "You restored {file}" : "Du återställde {file}",
    "{user} restored {file}" : "{user} återställde {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Du ändrade filnamn {oldfile} (dold) till {newfile} (dold)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Du ändrade filnamn {oldfile} (dold) till {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Du ändrade filnamn {oldfile} till {newfile} (dold)",
    "You renamed {oldfile} to {newfile}" : "Du ändrade filnamn {oldfile} till {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} ändrade filnamn {oldfile} (dold) till {newfile} (dold)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} ändrade filnamn {oldfile} (dold) till {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} ändrade filnamn {oldfile} till {newfile} (dold)",
    "{user} renamed {oldfile} to {newfile}" : "{user} ändrade filnamn {oldfile} till {newfile}",
    "You moved {oldfile} to {newfile}" : "Du flyttade {oldfile} till {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} flyttade {oldfile} till {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "En fil har lagts till eller tagits bort från dina <strong>favoriter</strong>",
    "Files" : "Filer",
    "A file or folder has been <strong>changed</strong>" : "En ny fil eller mapp har blivit <strong>ändrad</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "En favorit-fil eller mapp har blivit <strong>ändrad</strong>",
    "Failed to authorize" : "Det gick inte att auktorisera",
    "Invalid folder path" : "Ogiltig mappsökväg",
    "Folder not found" : "Mappen hittades inte",
    "The file cannot be found" : "Filen kan inte hittas",
    "The destination path does not exist: %1$s" : "Målsökvägen finns inte: %1$s",
    "You do not have permission to create a file at the specified location" : "Du har inte behörighet att skapa en fil på den angivna platsen",
    "The file could not be converted." : "Filen kunde inte konverteras.",
    "Could not get relative path to converted file" : "Kunde inte hämta relativ sökväg till den konverterade filen",
    "Limit must be a positive integer." : "Begränsningen måste vara ett positivt heltal.",
    "The replacement character may only be a single character." : "Ersättningstecknet får endast vara ett enda tecken.",
    "Filename sanitization already started." : "Filnamnssanering har redan påbörjats.",
    "No filename sanitization inprogress." : "Ingen filnamnssanering pågår.",
    "Favorite files" : "Favoritfiler",
    "No favorites" : "Inga favoriter",
    "More favorites" : "Fler favoriter",
    "Accept" : "Acceptera",
    "Reject" : "Avvisa",
    "Incoming ownership transfer from {user}" : "Inkommande ägaröverföring från {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Vill du acceptera {path}?\n\nNotera: Överföringen kan efter att du accepterat ta upp till 1 timme.",
    "Ownership transfer denied" : "Ägarskapsöverföring nekad",
    "Your ownership transfer of {path} was denied by {user}." : "Din ägaröverföring av {path} nekades av {user}.",
    "Ownership transfer failed" : "Ägarskapsöverföring misslyckades",
    "Your ownership transfer of {path} to {user} failed." : "Din ägaröverföring av {path} till {user} misslyckades.",
    "The ownership transfer of {path} from {user} failed." : "Din ägaröverföring av {path} från {user} misslyckades.",
    "Ownership transfer done" : "Ägarskapsöverföring klar",
    "Your ownership transfer of {path} to {user} has completed." : "Din ägaröverföring av {path} till {user} är klar.",
    "The ownership transfer of {path} from {user} has completed." : "Ägaröverföringen av {path} från {user} är klar.",
    "in %s" : "om %s",
    "Transferred from %1$s on %2$s" : "Överförd från %1$s på %2$s",
    "File Management" : "Filhantering",
    "Home" : "Hem",
    "Target folder does not exist any more" : "Målmapp existerar inte längre",
    "Reload current directory" : "Ladda om nuvarande mapp",
    "Go to the \"{dir}\" directory" : "Gå till \"{dir}\" mappen",
    "Current directory path" : "Aktuell katalogsökväg",
    "Your have used your space quota and cannot upload files anymore" : "Du har använt din utrymmeskvot och kan inte längre ladda upp filer",
    "You do not have permission to upload or create files here." : "Du har inte behörighet att ladda upp eller skapa filer här.",
    "Drag and drop files here to upload" : "Dra och släpp filer här för att ladda upp",
    "Favorite" : "Favorit",
    "Back" : "Tillbaka",
    "Toggle selection for file \"{displayName}\"" : "Växla markering för filen \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Växla markering för mappen \"{displayName}\"",
    "File is loading" : "Filen laddas",
    "Folder is loading" : "Mappen laddas",
    "Filename" : "Filnamn",
    "Folder name" : "Mappnamn",
    "This node is unavailable" : "Den här noden är inte tillgänglig",
    "Another entry with the same name already exists." : "En annan post med samma namn finns redan.",
    "Invalid filename." : "Ogiltigt filnamn.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Bytte namn på \"{oldName}\" till \"{newName}\"",
    "Rename file" : "Byt namn på fil",
    "Folder" : "Mapp",
    "Unknown file type" : "Okänd filtyp",
    "{ext} image" : "{ext} bild",
    "{ext} video" : "{ext} video",
    "{ext} audio" : "{ext} ljud",
    "{ext} text" : "{ext} text",
    "Pending" : "Väntar",
    "Unknown date" : "Okänt datum",
    "Clear filter" : "Rensa filter",
    "Modified" : "Ändrad",
    "Search everywhere" : "Sök överallt",
    "Type" : "Typ",
    "Active filters" : "Aktiva filter",
    "Remove filter" : "Ta bort filter",
    "Total rows summary" : "Sammanfattning antal rader",
    "Toggle selection for all files and folders" : "Växla markering för alla filer och mappar",
    "Name" : "Namn",
    "File type" : "Filtyp",
    "Size" : "Storlek",
    "{displayName}: failed on some elements" : "{displayName}: misslyckades för vissa element",
    "{displayName}: done" : "{displayName}: klar",
    "{displayName}: failed" : "{displayName}: misslyckades",
    "Actions" : "Funktioner",
    "(selected)" : "(vald)",
    "List of files and folders." : "Lista över filer och mappar.",
    "You have used your space quota and cannot upload files anymore." : "Du har använt din utrymmeskvot och kan inte längre ladda upp filer.",
    "Column headers with buttons are sortable." : "Kolumnrubriker med knappar är sorterbara.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Denna lista är inte helt återgiven av prestandaskäl. Filerna kommer att renderas när du navigerar genom listan.",
    "File not found" : "Filen kunde inte hittas",
    "_{count} selected_::_{count} selected_" : ["{count} vald","{count} valda"],
    "Search everywhere …" : "Sök överallt …",
    "Search here …" : "Sök här …",
    "Search scope options" : "Alternativ för sökomfång",
    "Search here" : "Sök här",
    "{usedQuotaByte} used" : "{usedQuotaByte} använt",
    "{used} of {quota} used" : "{used} av {quota} använt",
    "{relative}% used" : "{relative}% använt",
    "Could not refresh storage stats" : "Det gick inte att uppdatera lagringsstatistiken",
    "Your storage is full, files can not be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
    "Storage information" : "Lagringsinformation",
    "Storage quota" : "Lagringskvot",
    "New folder" : "Ny mapp",
    "Create new folder" : "Skapa ny mapp",
    "This name is already in use." : "Namnet används redan.",
    "Create" : "Skapa",
    "Files starting with a dot are hidden by default" : "Filer som börjar med en punkt är dolda som standard",
    "Failed to start filename sanitization." : "Kunde inte starta filnamnssanering.",
    "Failed to refresh filename sanitization status." : "Kunde inte uppdatera status för filnamnssanering.",
    "Filename sanitization in progress." : "Filnamnssanering pågår.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "För närvarande har {processedUsers} av {totalUsers} konton redan behandlats.",
    "Preparing …" : "Förbereder …",
    "Refresh" : "Uppdatera",
    "All files have been santized for Windows filename support." : "Alla filer har sanerats för att stödja filnamn i Windows.",
    "Some files could not be sanitized, please check your logs." : "Vissa filer kunde inte saneras, kontrollera loggarna.",
    "Sanitization errors" : "Saneringsfel",
    "Not sanitized filenames" : "Ej sanerade filnamn",
    "Windows filename support has been enabled." : "Stöd för filnamn i Windows har aktiverats.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Detta förhindrar användare från att skapa nya filer med filnamn som inte stöds, men befintliga filer har ännu inte bytt namn och kan därför fortfarande orsaka synkroniseringsproblem i Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Du kan starta en namnändring av filer med ogiltiga filnamn. Detta görs i bakgrunden och kan ta en stund.",
    "Please note that this may cause high workload on the sync clients." : "Observera att detta kan orsaka hög belastning på synkklienterna.",
    "Limit" : "Begränsning",
    "This allows to configure how many users should be processed in one background job run." : "Detta låter dig konfigurera hur många användare som ska behandlas per körning av ett bakgrundsjobb.",
    "Sanitize filenames" : "Sanera filnamn",
    "(starting)" : "(startar)",
    "Fill template fields" : "Fyll mallfält",
    "Submitting fields …" : "Skickar fält ...",
    "Submit" : "Skicka",
    "Choose a file or folder to transfer" : "Välj en fil eller mapp att överföra",
    "Transfer" : "Överför",
    "Transfer {path} to {userid}" : "Överför {path} till {userid}",
    "Invalid path selected" : "Ogiltig sökväg vald",
    "Unknown error" : "Okänt fel",
    "Ownership transfer request sent" : "Förfrågan om ägaröverföring skickad",
    "Cannot transfer ownership of a file or folder you do not own" : "Det går inte att överföra äganderätten till en fil eller mapp som du inte äger",
    "Transfer ownership of a file or folder" : "Överför ägarskap av en fil eller mapp",
    "Choose file or folder to transfer" : "Välj fil eller mapp att överföra",
    "Change" : "Ändra",
    "New owner" : "Ny ägare",
    "Keep {old}" : "Behåll {old}",
    "Keep without extension" : "Behåll utan filändelse",
    "Use {new}" : "Använd {new}",
    "Remove extension" : "Ta bort filändelse",
    "Change file extension" : "Ändra filändelse",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Att ändra filtillägget från \"{old}\" till \"{new}\" kan göra filen oläsbar.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Att ta bort filtillägget \"{old}\" kan göra filen oläsbar.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Att lägga till filtillägget \"{new}\" kan göra filen oläsbar.",
    "Do not show this dialog again." : "Visa inte denna dialog igen.",
    "Select file or folder to link to" : "Välj fil eller mapp att länka till",
    "Choose {file}" : "Välj {file}",
    "Share" : "Dela",
    "Shared by link" : "Delad via länk",
    "Shared" : "Delad",
    "Switch to list view" : "Växla till listvy",
    "Switch to grid view" : "Växla till rutnätsvy",
    "The file could not be found" : "Filen kunde inte hittas",
    "Upload was cancelled by user" : "Uppladdningen avbröts av användaren",
    "Not enough free space" : "Inte tillräckligt med ledigt utrymme",
    "Operation is blocked by access control" : "Operationen blockeras av åtkomstkontroll",
    "Error during upload: {message}" : "Fel vid uppladdning: {message}",
    "Error during upload, status code {status}" : "Fel vid uppladdning, statuskod {status}",
    "Unknown error during upload" : "Okänt fel under uppladdning",
    "Loading current folder" : "Laddar aktuell mapp",
    "Retry" : "Försök igen",
    "No files in here" : "Inga filer kunde hittas",
    "Upload some content or sync with your devices!" : "Ladda upp innehåll eller synkronisera med dina enheter!",
    "Go back" : "Gå tillbaks",
    "Views" : "Vyer",
    "Files settings" : "Filinställningar",
    "Your files" : "Dina filer",
    "Open in files" : "Öppna i filer",
    "File cannot be accessed" : "Det går inte att komma åt filen",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Filen kunde inte hittas eller så har du inte behörighet att visa den. Be avsändaren att dela den.",
    "No search results for “{query}”" : "Inget sökresultat för “{query}”",
    "Search for files" : "Sök efter filer",
    "Clipboard is not available" : "Urklipp är inte tillgängligt",
    "WebDAV URL copied" : "WebDAV-adress kopierad",
    "General" : "Allmänt",
    "Default view" : "Standardvy",
    "All files" : "Alla filer",
    "Personal files" : "Personliga filer",
    "Sort favorites first" : "Sortera favoriter först",
    "Sort folders before files" : "Sortera mappar före filer",
    "Folder tree" : "Mappträd",
    "Appearance" : "Utseende",
    "Show hidden files" : "Visa dolda filer",
    "Show file type column" : "Visa kolumn för filtyp",
    "Show file extensions" : "Visa filändelser",
    "Crop image previews" : "Beskär förhandsgranskningar för bilder",
    "Additional settings" : "Övriga inställningar",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy" : "Kopiera",
    "How to access files using WebDAV" : "Hur du får åtkomst till filer via WebDAV",
    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Tvåfaktorsautentisering är aktiverad för ditt konto och därför måste du använda ett applösenord för att ansluta en extern WebDAV-klient.",
    "Warnings" : "Varningar",
    "Warn before changing a file extension" : "Varna innan en filändelse ändras",
    "Warn before deleting files" : "Varna innan filer tas bort",
    "Keyboard shortcuts" : "Tangentbordsgenvägar",
    "File actions" : "Filåtgärder",
    "Rename" : "Byt namn",
    "Delete" : "Radera",
    "Add or remove favorite" : "Lägg till eller ta bort favorit",
    "Manage tags" : "Hantera taggar",
    "Selection" : "Markerade",
    "Select all files" : "Välj alla filer",
    "Deselect all" : "Avmarkera alla",
    "Select or deselect" : "Markera eller avmarkera",
    "Select a range" : "Markera ett intervall",
    "Navigation" : "Navigering",
    "Go to parent folder" : "Gå till överordnad mapp",
    "Go to file above" : "Gå till filen ovanför",
    "Go to file below" : "Gå till filen nedanför",
    "Go left in grid" : "Gå åt vänster i rutnätet",
    "Go right in grid" : "Gå åt höger i rutnätet",
    "View" : "Visa",
    "Toggle grid view" : "Växla rutnätsvy",
    "Open file sidebar" : "Öppna filens sidofält",
    "Show those shortcuts" : "Visa dessa genvägar",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Tillåt att begränsa filnamn för att säkerställa att filer kan synkroniseras med alla klienter. Som standard är alla filnamn som är giltiga på POSIX (t.ex. Linux eller macOS) tillåtna.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "När Windows-kompatibla filnamn har aktiverats kan befintliga filer inte längre ändras, men de kan byta namn till giltiga nya namn av sin ägare.",
    "Failed to toggle Windows filename support" : "Kunde inte växla stöd för filnamn i Windows",
    "Files compatibility" : "Filkompatibilitet",
    "Enforce Windows compatibility" : "Tvinga Windows-kompatibilitet",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Detta kommer att blockera filnamn som inte är giltiga på Windows-system, som att använda reserverade namn eller specialtecken. Men detta kommer inte att framtvinga kompatibiliteten för skiftlägeskänslighet.",
    "You" : "Du",
    "Shared multiple times with different people" : "Delad flera gånger med olika personer",
    "Unable to change the favorite state of the file" : "Kan inte ändra filens favoritstatus",
    "Error while loading the file data" : "Fel vid inläsning av fildata",
    "Owner" : "Ägare",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till i favoriter",
    "Tags" : "Taggar",
    "Blank" : "Tom",
    "Unable to create new file from template" : "Kunde inte skapa fil från mall",
    "Pick a template for {name}" : "Välj en mall för {name}",
    "Create a new file with the selected template" : "Skapa en ny fil med den valda mallen",
    "Creating file" : "Skapar fil",
    "Save as {displayName}" : "Spara som {displayName}",
    "Save as …" : "Spara som …",
    "Converting files …" : "Konverterar filer ...",
    "Failed to convert files: {message}" : "Kunde inte konvertera filer: {message}",
    "All files failed to be converted" : "Alla filer misslyckades med att konverteras",
    "One file could not be converted: {message}" : "En fil kunde inte konverteras: {message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["En fil kunde inte konverteras","%n filer kunde inte konverteras"],
    "_One file successfully converted_::_%n files successfully converted_" : ["En fil har konverterats","%n filer har konverterats"],
    "Files successfully converted" : "Filerna har konverterats",
    "Failed to convert files" : "Det gick inte att konvertera filer",
    "Converting file …" : "Konverterar fil ...",
    "File successfully converted" : "Filen har konverterats",
    "Failed to convert file: {message}" : "Kunde inte konvertera filen: {message}",
    "Failed to convert file" : "Kunde inte konvertera filen",
    "Leave this share" : "Lämna denna delning",
    "Leave these shares" : "Lämna dessa delningar",
    "Disconnect storage" : "Koppla bort lagring",
    "Disconnect storages" : "Koppla bort lagringar",
    "Delete permanently" : "Ta bort permanent",
    "Delete and unshare" : "Radera och sluta dela",
    "Delete file" : "Ta bort fil",
    "Delete files" : "Radera filer",
    "Delete folder" : "Radera mapp",
    "Delete folders" : "Radera mappar",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Du är på väg att permanent ta bort {count} objekt","Du är på väg att permanent ta bort {count} objekt"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Du är på väg att ta bort {count} objekt","Du är på väg att ta bort {count} objekt"],
    "Confirm deletion" : "Bekräfta radering",
    "Cancel" : "Avbryt",
    "Download" : "Hämta",
    "The requested file is not available." : "Den begärda filen är inte tillgänglig.",
    "The requested files are not available." : "De begärda filerna är inte tillgängliga.",
    "Moving \"{source}\" to \"{destination}\" …" : "Flyttar \"{source}\" till \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopierar \"{source}\" till \"{destination}\" …",
    "Destination is not a folder" : "Destinationen är inte en mapp",
    "This file/folder is already in that directory" : "Den här filen/mappen finns redan i den katalogen",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Du kan inte flytta en fil/mapp till sig själv eller till en undermapp till sig själv",
    "(copy)" : "(kopia)",
    "(copy %n)" : "(kopia %n)",
    "A file or folder with that name already exists in this folder" : "En fil eller mapp med det namnet finns redan i den här mappen",
    "The files are locked" : "Filerna är låsta",
    "The file does not exist anymore" : "Filen finns inte längre",
    "Choose destination" : "Välj destination",
    "Copy to {target}" : "Kopiera till {target}",
    "Move to {target}" : "Flytta till {target}",
    "Move" : "Flytta",
    "Move or copy operation failed" : "Flytta eller kopiera misslyckades",
    "Move or copy" : "Flytta eller kopiera",
    "Open folder {displayName}" : "Öppna mappen {displayName}",
    "Open in Files" : "Öppna i Filer",
    "Open locally" : "Öppna lokalt",
    "Failed to redirect to client" : "Det gick inte att omdirigera till klienten",
    "Open file locally" : "Öppna filen lokalt",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Filen bör nu öppnas på din enhet. Om den inte gör det, kontrollera att du har installerat skrivbordsappen.",
    "Retry and close" : "Försök igen och stäng",
    "Open online" : "Öppna online",
    "Details" : "Detaljer",
    "View in folder" : "Utforska i mapp",
    "Today" : "Idag",
    "Last 7 days" : "Senaste 7 dagarna",
    "Last 30 days" : "Senaste 30 dagarna",
    "This year ({year})" : "I år ({year})",
    "Last year ({year})" : "Förra året ({year})",
    "Documents" : "Dokument",
    "Spreadsheets" : "Kalkylblad",
    "Presentations" : "Presentationer",
    "PDFs" : "PDF-filer",
    "Folders" : "Mappar",
    "Audio" : "Ljud",
    "Images" : "Bilder",
    "Videos" : "Videor",
    "Created new folder \"{name}\"" : "Skapat ny mapp \"{name}\"",
    "Unable to initialize the templates directory" : "Kunde inte initialisera mall-mappen",
    "Create templates folder" : "Skapa mallmapp",
    "Templates" : "Mallar",
    "New template folder" : "Ny mallmapp",
    "In folder" : "I mapp",
    "Search in all files" : "Sök i alla filer",
    "Search in folder: {folder}" : "Sök i mapp: {folder}",
    "One of the dropped files could not be processed" : "En av de släppta filerna kunde inte bearbetas",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Din webbläsare stöder inte Filesystem API. Mappar kommer inte att laddas upp",
    "No files to upload" : "Inga filer att ladda upp",
    "Unable to create the directory {directory}" : "Det gick inte att skapa mappen {directory}",
    "Some files could not be uploaded" : "Vissa filer kunde inte laddas upp",
    "Files uploaded successfully" : "Filerna uppladdade",
    "No files to process" : "Inga filer att bearbeta",
    "Some files could not be copied" : "Vissa filer kunde inte kopieras",
    "Some files could not be moved" : "Vissa filer kunde inte flyttas",
    "Files copied successfully" : "Filerna kopierade",
    "Files moved successfully" : "Filerna flyttade",
    "Conflicts resolution skipped" : "Konfliktlösning hoppades över",
    "Upload cancelled" : "Uppladdning avbruten",
    "Could not rename \"{oldName}\", it does not exist any more" : "Kunde inte byta namn på \"{oldName}\", den finns inte längre",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{newName}\" används redan i mappen \"{dir}\". Välj ett annat namn.",
    "Could not rename \"{oldName}\"" : "Kunde inte byta namn på \"{oldName}\"",
    "This operation is forbidden" : "Denna operation är förbjuden",
    "This folder is unavailable, please try again later or contact the administration" : "Denna mapp är inte tillgänglig, försök igen senare eller kontakta administratören",
    "Storage is temporarily not available" : "Lagring är tillfälligt inte tillgänglig",
    "Unexpected error: {error}" : "Oväntat fel: {error}",
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
    "_%n hidden_::_%n hidden_" : ["%n gömd","%n gömd"],
    "Filename must not be empty." : "Filnamn får inte vara tomt.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" är inte tillåtet i ett filnamn.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" är ett reserverat namn och inte tillåtet som filnamn.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" är inte en tillåten filtyp.",
    "Filenames must not end with \"{extension}\"." : "Filnamn får inte sluta med \"{extension}\".",
    "List of favorite files and folders." : "Lista över favoritfiler och mappar.",
    "No favorites yet" : "Inga favoriter ännu",
    "Files and folders you mark as favorite will show up here" : "Filer och mappar markerade som favoriter kommer att visas här",
    "List of your files and folders." : "Lista över dina filer och mappar.",
    "List of your files and folders that are not shared." : "Lista över dina filer och mappar som inte delas.",
    "No personal files found" : "Inga personliga filer hittades",
    "Files that are not shared will show up here." : "Filer som inte delas kommer att visas här.",
    "Recent" : "Senaste",
    "List of recently modified files and folders." : "Lista över nyligen ändrade filer och mappar.",
    "No recently modified files" : "Inga nyligen ändrade filer",
    "Files and folders you recently modified will show up here." : "Filer och mappar som du nyligen ändrat kommer att visas här.",
    "Search" : "Sök",
    "Search results within your files." : "Sökresultat i dina filer.",
    "No entries found in this folder" : "Inget innehåll hittades i denna mapp",
    "Select all" : "Välj allt",
    "Upload too large" : "För stor uppladdning",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerna du försöker ladda upp överstiger den maximala storleken för filöverföringar på servern.",
    "File could not be found" : "Fil kunde inte hittas",
    "Show list view" : "Visa listvy",
    "Show grid view" : "Visa rutnätsvy",
    "Close" : "Stäng",
    "Could not create folder \"{dir}\"" : "Kunde inte skapa mapp \"{dir}\"",
    "This will stop your current uploads." : "Detta kommer att stoppa nuvarande uppladdningar.",
    "Upload cancelled." : "Uppladdning avbruten.",
    "Processing files …" : "Bearbetar filer ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan inte ladda upp {filename} eftersom den antingen är en mapp eller har 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Inte tillräckligt med ledigt utrymme, du laddar upp {size1} men endast {size2} finns kvar.",
    "Target folder \"{dir}\" does not exist any more" : "Målmapp \"{dir}\" existerar inte mer",
    "An unknown error has occurred" : "Ett okänt fel uppstod",
    "File could not be uploaded" : "Filen kunde inte laddas upp",
    "Uploading …" : "Laddar upp ..",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Laddar upp … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Uppladdning av det här objektet stöds inte",
    "Error when assembling chunks, status code {status}" : "Fel vid ihopsättning av bitarna: statuskod:  {status}",
    "Choose target folder" : "Välj målmapp",
    "Set reminder" : "Ställ in påminnelse",
    "Edit locally" : "Redigera lokalt",
    "Open" : "Öppna",
    "Could not load info for file \"{file}\"" : "Kunde inte läsa in information för filen \"{file}\"",
    "Please select tag(s) to add to the selection" : "Vänligen välj tagg(ar) att lägga till i ditt urval",
    "Apply tag(s) to selection" : "Lägg till tagg(ar) i ditt urval",
    "Select directory \"{dirName}\"" : "Välj mapp \"{dirName}\"",
    "Select file \"{fileName}\"" : "Välj fil \"{fileName}\"",
    "Unable to determine date" : "Misslyckades avgöra datum",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denna katalog är inte tillgänglig, kontrollera loggarna eller kontakta administratören",
    "Could not move \"{file}\", target exists" : "Kunde inte flytta \"{file}\", filen existerar redan",
    "Could not move \"{file}\"" : "Kunde inte flytta \"{file}\"",
    "copy" : "kopia",
    "Could not copy \"{file}\", target exists" : "Kunde inte kopiera \"{file}\", filen existerar redan",
    "Could not copy \"{file}\"" : "Kunde inte kopiera \"{file}\"",
    "Copied {origin} inside {destination}" : "Kopierade {origin} till {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierade {origin} och {nbfiles} andra filer i {destination}",
    "{newName} already exists" : "{newName} existerar redan",
    "Could not create file \"{file}\"" : "Kunde inte skapa fil \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Kunde inte skapa fil \"{file}\" därför att den redan existerar",
    "Could not create folder \"{dir}\" because it already exists" : "Kunde inte skapa \"{dir}\" därför att den redan existerar",
    "Could not fetch file details \"{file}\"" : "Kunde inte hämta filinformation \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Fel när \"{fileName}\" skulle raderas.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Inga sökresultat i andra mappar för {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Ange mer än två tecken för att söka i andra mappar",
    "{dirs} and {files}" : "{dirs} och {files}",
    "_including %n hidden_::_including %n hidden_" : ["inkluderar %n dold","inkluderar %n dolda"],
    "You do not have permission to upload or create files here" : "Du har inte behörighet att ladda upp eller skapa filer här",
    "_Uploading %n file_::_Uploading %n files_" : ["Laddar upp %n fil","Laddar upp %n filer"],
    "New" : "Ny",
    "New file/folder menu" : "Ny fil/mapp -meny",
    "Select file range" : "Välj filintervall",
    "{used}%" : "{used}%",
    "{used} used" : "{used} använt",
    "\"{name}\" is an invalid file name." : "\"{name}\" är ett ogiltigt filnamn.",
    "File name cannot be empty." : "Filnamn kan inte vara tomt.",
    "\"/\" is not allowed inside a file name." : "\"/\" är inte tillåtet i ett filnamn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" är inte en tillåten filtyp",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Lagring av {owner}  är full, filer kan inte uppdateras eller synkroniseras längre!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppmapp \"{mountPoint}\" är full, filer kan inte uppdateras eller synkroniseras längre!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Extern lagring \"{mountPoint}\" är full, filer kan inte uppdateras eller synkroniseras längre!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lagring av  {owner}  är nästan full  ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppmapp \"{mountPoint}\" är nästan full ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Extern lagring \"{mountPoint}\" är nästan full ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Ditt lagringsutrymme är nästan fullt ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matcha \"{filter}\"","matcha \"{filter}\""],
    "Direct link was copied (only works for people who have access to this file/folder)" : "Direktlänk kopierades (fungerar endast för användare som har tillgång till denna fil/mapp)",
    "Path" : "Sökväg",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Favored" : "Favoriserad",
    "Favor" : "Favorisera",
    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiera direktlänk (fungerar endast för användare som har åtkomst till denna fil/mapp)",
    "Upload file" : "Ladda upp fil",
    "Not favored" : "Inte favoriserad",
    "An error occurred while trying to update the tags" : "Fel vid uppdatering av taggarna",
    "Upload (max. %s)" : "Ladda upp (högst %s)",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-åtgärden har utförts",
    "\"{displayName}\" action failed" : "\"{displayName}\"-åtgärden misslyckades",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" misslyckades med vissa element",
    "\"{displayName}\" batch action executed successfully" : "Batchåtgärden \"{displayName}\" har utförts",
    "Submitting fields…" : "Skickar fält...",
    "Filter filenames…" : "Filtrera filnamn...",
    "WebDAV URL copied to clipboard" : "WebDAV URL kopierad till urklipp",
    "Enable the grid view" : "Aktivera rutnätsvy",
    "Enable folder tree" : "Aktivera mappträd",
    "Copy to clipboard" : "Kopiera till urklipp",
    "Use this address to access your Files via WebDAV" : "Använd denna adress för att komma åt dina filer med WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Om du har aktiverat 2FA måste du skapa och använda ett nytt applösenord genom att klicka här.",
    "Deletion cancelled" : "Radering avbruten",
    "Move cancelled" : "Flytt avbruten",
    "Cancelled move or copy of \"{filename}\"." : "Avbröt flytt eller kopiering av \"{filename}\".",
    "Cancelled move or copy operation" : "Flytta eller kopiera avbröts",
    "Open details" : "Öppna detaljer",
    "Photos and images" : "Foton och bilder",
    "New folder creation cancelled" : "Skapandet av ny mapp avbröts",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mapp","{folderCount} mappar"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fil","{fileCount} filer"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fil och {folderCount} mapp","1 fil och {folderCount} mappar"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fil och 1 mapp","{fileCount} filer och 1 mapp"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} filer och {folderCount} mappar",
    "All folders" : "Alla mappar",
    "Personal Files" : "Personliga filer",
    "Text file" : "Textfil",
    "New text file.txt" : "Ny textfil.txt",
    "%1$s (renamed)" : "%1$s (omdöpt)",
    "renamed file" : "omdöpt fil",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "När Windows-kompatibla filnamn har aktiverats kan befintliga filer inte längre ändras, men de kan byta namn till giltiga nya namn av sin ägare.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Det är också möjligt att migrera filer automatiskt efter att den här inställningen har aktiverats. Se dokumentationen om kommandot occ för mer information.",
    "Filter file names …" : "Filtrera filnamn …",
    "Prevent warning dialogs from open or reenable them." : "Förhindra varningsdialoger från att öppnas eller aktivera dem igen.",
    "Show a warning dialog when changing a file extension." : "Visa en varningsdialog vid ändring av filändelse.",
    "Speed up your Files experience with these quick shortcuts." : "Snabba upp din upplevelse i Filer med dessa smarta genvägar.",
    "Open the actions menu for a file" : "Öppna åtgärdsmenyn för en fil",
    "Rename a file" : "Byt namn på en fil",
    "Delete a file" : "Ta bort en fil",
    "Favorite or remove a file from favorites" : "Lägg till eller ta bort en fil från favoriter",
    "Manage tags for a file" : "Hantera taggar för en fil",
    "Deselect all files" : "Avmarkera alla filer",
    "Select or deselect a file" : "Markera eller avmarkera en fil",
    "Select a range of files" : "Markera ett filintervall",
    "Navigate to the parent folder" : "Gå till överordnad mapp",
    "Navigate to the file above" : "Gå till filen ovan",
    "Navigate to the file below" : "Gå till filen nedan",
    "Navigate to the file on the left (in grid mode)" : "Gå till filen till vänster (i rutnätsvy)",
    "Navigate to the file on the right (in grid mode)" : "Gå till filen till höger (i rutnätsvy)",
    "Toggle the grid view" : "Växla rutnätsvy",
    "Open the sidebar for a file" : "Öppna sidofältet för en fil"
},
"nplurals=2; plural=(n != 1);");
